@@ -7,7 +7,7 @@ multiscale ReferenceFileSystem JSON file for a sequence of cloud optimized
 GeoTIFF (COG) files stored on S3. The tiles of the COG files are used as
 chunks. No additional Numcodecs codec needs to be registered since the COG
 files use Zlib compression. A Xarray dataset is created from the
-ReferenceFileSystem file and a subset of the dataset is ploted.
+ReferenceFileSystem file and a subset of the dataset is plotted.
 
 See https://github.com/cgohlke/tifffile/issues/125
 
@@ -27,7 +27,7 @@ fs = fsspec.filesystem('s3', **remote_options)
 files = [f's3://{f}' for f in fs.ls('/rsignellbucket1/lcmap/cog')]
 
 # write the ReferenceFileSystem of each file to a JSON file
-with open('issue125.json', 'w', newline='\n') as jsonfile:
+with open('issue125.json', 'w', encoding='utf-8', newline='\n') as jsonfile:
     for i, filename in enumerate(tifffile.natural_sorted(files)):
         url, name = filename.rsplit('/', 1)
         with fs.open(filename) as fh:
